@@ -5,7 +5,7 @@ from math import sqrt
 from typing import TypedDict
 
 import torch
-from pyapes.core.backend import DType
+from pyapes.backend import DType
 from torch import Tensor
 
 
